@@ -9,7 +9,7 @@ use HTML::Parser;
 use HTML::Form;
 use Digest::MD5();
 
-our $VERSION = '7.00';
+our $VERSION = '7.03.1';
 
 # $Id: $
 # $Log: LaPoste.pm,v $
@@ -154,7 +154,7 @@ my %img_md5sum_to_number = (
     '163279f1a46082408613d12394e4042a' => 6,
     'b0a9c740c4cada01eb691b4acda4daea' => 7,
     '3c4307ee92a1f3b571a3c542eafcb330' => 8,
-    'c5b854ae314b61ba42948909e0b2eae7' => 9,
+    'dbccecfa2206bfdb4ca891476404cc68' => 9,
 );
 
 sub _get_number_mangling_map {
@@ -209,7 +209,7 @@ sub _list_accounts {
 	if (ref $account && $account_no) {
 	    my $url = $account->[1];
 	    $url =~ s/typeRecherche=1$/typeRecherche=10/; # 400 last operations
-	    $url =~ s!/relevesCCP/\d-!/relevesCCP/!; # remove the unneeded number (otherwise one get an intermediate page)
+	    $url =~ s!/(relevesCCP|relevesEpargnes)/\d-!/$1/!; # remove the unneeded number (otherwise one get an intermediate page)
 	    {
 	        name => $account->[0],
 	        account_no => $account_no, 
@@ -327,11 +327,12 @@ sub statements {
 	    $balance =~ s/<.*?>\s*//g; # (since 24/06/2004) remove: </span><span class="soldeur"> or <strong>...</strong>
 	    $normalize_number->($balance);
 	};
+	my $fourth_column_is_Francs = $html =~ m!>Francs.*</th>!;
 	my $l = $parse_table->($html);
 
-	    # drop first line which contain columns title
 	    @$l = map {
-		my ($date, $description, $amount) = @$_;
+		my ($date, $description, $amount_neg, $amount_pos) = @$_;
+		my $amount = $normalize_number->($amount_neg) + ($fourth_column_is_Francs ? 0 : $normalize_number->($amount_pos));
 		$date && $date =~ m!(\d+)/(\d+)! ? [ $date, $description, $amount ] : ();
 	    } @$l;
 
@@ -341,7 +342,7 @@ sub statements {
 	    my ($day, $month) = $date =~ m|(\d+)/(\d+)|;
 	    $year-- if $month > $prev_month;
 	    $prev_month = $month;
-	    Finance::Bank::LaPoste::Statement->new(day => $day, month => $month, year => $year, description => $description, amount => $normalize_number->($amount));
+	    Finance::Bank::LaPoste::Statement->new(day => $day, month => $month, year => $year, description => $description, amount => $amount);
 	} @$l ];
     };
     @{$self->{statements}};
